@@ -1,7 +1,7 @@
-from astrape.models.models_lightning import MLP, ContractingMLP, CustomMLP, VGG, UNet, Generator, Discriminator
+from astrape.models.models_lightning import MLP, ContractingMLP, CustomMLP, VGG, UNet
 from astrape.models.model_buildingblocks import DoubleConv, Down, Up
 from astrape.utilities.utils_lightning import set_default_parameters
-from astrape.constants import DEFAULT_BATCH_SIZE, DEFAULT_LR, DEFAULT_OPTIMIZER_TYPE
+#from astrape.constants import DEFAULT_BATCH_SIZE, DEFAULT_LR, DEFAULT_OPTIMIZER_TYPE
 __all__ = [
     'MLP', 
     'ContractingMLP', 
@@ -13,8 +13,5 @@ __all__ = [
     'DoubleConv', 
     'Down', 
     'Up', 
-    'set_default_parameters',
-    'DEFAULT_BATCH_SIZE',
-    'DEFAULT_LR',
-    'DEFAULT_OPTIMIZER_TYPE'
+    'set_default_parameters'
     ]
